@@ -118,8 +118,8 @@ def time_trace(f, gatherer, min_duration, is_template=False):
 def register_timing(config):
     timing_modules = ['timing_urllib', 'timing_urllib2', 'timing_urllib3',
                       'timing_requests', 'timing_httplib', 'timing_pysolr',
-                      'timing_mako', 'timing_jinja2', 'timing_pymongo',
-                      'timing_django_templates']
+                      'timing_chameleon', 'timing_mako', 'timing_jinja2',
+                      'timing_pymongo', 'timing_django_templates']
 
     for mod in timing_modules:
         min_time = config['timing'].get(mod.replace("timing_", '').lower())
