@@ -78,6 +78,10 @@ class ErrormatorWSGIWrapper(object):
             errormator_storage.thread_stats['main'] = end_time - start_time
             stats, slow_calls = errormator_storage.get_thread_stats()
             errormator_storage.clear()
+            if 'errormator.__traceback' in environ:
+                # get traceback gathered by tween
+                traceback = environ['errormator.__traceback']
+                del environ['errormator.__traceback']
             if traceback and self.errormator_client.config['report_errors']:
                 http_status = 500
             elif (self.errormator_client.config['report_404'] and
@@ -91,6 +95,9 @@ class ErrormatorWSGIWrapper(object):
                                                  http_status=http_status,
                     start_time=datetime.datetime.utcfromtimestamp(start_time),
                     request_stats=stats)
+                # dereference
+                del traceback
+                traceback = True
             delta = datetime.timedelta(seconds=(end_time - start_time))
             self.errormator_client.save_request_stats(stats)
             if self.errormator_client.config['slow_requests']:
